summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/selectopdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/selectopdlg.h')
-rw-r--r--umbrello/umbrello/dialogs/selectopdlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/selectopdlg.h b/umbrello/umbrello/dialogs/selectopdlg.h
index 4bbcf52b..3c12b1b1 100644
--- a/umbrello/umbrello/dialogs/selectopdlg.h
+++ b/umbrello/umbrello/dialogs/selectopdlg.h
@@ -39,14 +39,15 @@ class UMLView;
class SelectOpDlg : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a SelectOpDlg instance.
*
* @param parent The parent to this instance.
* @param c The concept to get the operations from.
*/
- SelectOpDlg(UMLView * parent, UMLClassifier * c);
+ SelectOpDlg(UMLView * tqparent, UMLClassifier * c);
/**
* Standard deconstructor.
@@ -39,14 +39,15 @@ class UMLView;
* Constructs a SelectOpDlg instance.
*
- * @param parent The parent to this instance.
+ * @param tqparent The tqparent to this instance.
* @param c The concept to get the operations from.
*/